BROKER_JAR="dcv-session-manager-broker-2024.0.jar"
BROKER_DIR="/usr/share/dcv-session-manager-broker/lib"
CONF_DIR="/etc/dcv-session-manager-broker"
CHROOT_DIR=/var/lib/dcvsmbroker
SERVICE_USER="dcvsmbroker"

JVM_OPTS="-Xmx2g -Xms512m"
BROKER_COMMAND_ENV="-Dfile.encoding=UTF-8 -Dlogback.configurationFile=${CONF_DIR}/logback.xml"
BROKER_COMMAND_JAR="${BROKER_DIR}/${BROKER_JAR}"
BROKER_CONF_FILE="${CONF_DIR}/session-manager-broker.properties"
BROKER_CONF_FILE_PROPERTY="--configuration-file ${BROKER_CONF_FILE}"
BROKER_CONF_PARAM_JAVA_HOME="broker-java-home"
REQUIRED_JAVA_VERSION_MAJOR=11
LOG_FILE_SUFFIX="-DLOG_FILE_SUFFIX="

function die {
    echo -e "$1" >&2
    exit 1
}

function warn {
    echo -e "[WARN] $1" >&2
}

function check_user {
  _allowed_user="$1"
  _error_message="$2"
  _user=$(whoami)

  [ "${_user}" != "${_allowed_user}" ] && die "${_error_message}"
}

function get_value_from_conf {
    local _conf_file="$1"
    local _param="$2"

    < "${_conf_file}" grep "^[[:space:]]*${_param}" | cut -d "=" -f2 | tr -d "[:space:]"
}

function get_java_cmd {
    local _java_home

    _java_home=$(get_value_from_conf "${BROKER_CONF_FILE}" ${BROKER_CONF_PARAM_JAVA_HOME})
    if [ "${_java_home}" ]; then
        echo "${_java_home}/bin/java"
    else
        echo "java"
    fi
}

function check_java_version {
    local _java
    local _required_java_major
    local _user
    local _sudo_cmd
    local _output
    local _version
    local _major _minor

    _java="$1"
    _required_java_major="$2"
    _user=$(whoami)

    [ "${_user}" = "root" ] && _sudo_cmd="sudo -u ${SERVICE_USER}"
    if ! _output=$(${_sudo_cmd} "${_java}" -version 2>&1); then
        warn "${_output}"
        warn "Java is not installed or not working properly using service user ${SERVICE_USER}"
        return 1
    else
        _version=$(echo "${_output}" | awk -F '"' '/version/ {print $2}')
        IFS=. read -r _major _minor <<< "${_version}"
        if [ "${_major}" -ne "${_required_java_major}" ]; then
            warn "Java version in use is ${_version}, but DCV Session Manager Broker requires Java ${_required_java_major}"
            warn "Please check your Java installation or set the 'broker-java-home' parameter inside the Broker configuration file to target a specific Java version\n"
            return 0
        fi
    fi
}
