#!/bin/bash

BROKER_BIN_DIR="/usr/share/dcv-session-manager-broker/bin"
OUTPUT_FOLDER="/etc/dcv-session-manager-broker/gateway-creds"

source "${BROKER_BIN_DIR}/common.sh"

function get_cert_config {
    local _constraint

    if [ "$1" = "ca" ]; then
        _constraint="
            basicConstraints=critical,CA:TRUE,pathlen:0
            keyUsage=critical,keyCertSign,cRLSign"
    else
        _constraint="
            authorityKeyIdentifier=keyid,issuer
            basicConstraints=CA:FALSE
            keyUsage=digitalSignature,nonRepudiation,keyEncipherment,dataEncipherment
            subjectAltName=DNS:localhost"
    fi

    echo "
        [req]
        distinguished_name=dn
        [dn]
        [ext]
        $_constraint"
}


function gen_ca_issue_cert {
    local _where="$1"
    local _prefix="$2"
    local _subject="$3"

    openssl req -new -x509 -nodes -newkey rsa:4096 -sha256 -days 365 -subj "$_subject" -extensions ext -config <(get_cert_config ca) -keyout "${_where}/${_prefix}_ca_key.pem" -out "${_where}/${_prefix}_ca_cert.pem" || return 1
    openssl req -new -nodes -newkey rsa:4096 -sha256 -subj "/C=US/CN=localhost" -keyout "${_where}/${_prefix}_key.pem" -out "${_where}/${_prefix}_cert.pem.csr" || return 1
    openssl x509 -req -in "${_where}/${_prefix}_cert.pem.csr" -CA "${_where}/${_prefix}_ca_cert.pem" -CAkey "${_where}/${_prefix}_ca_key.pem" -CAcreateserial -sha256 -days 365 -extensions ext -extfile <(get_cert_config pem) -out "${_where}/${_prefix}_cert.pem" || return 1
}

function generate_jks_password {
    < /dev/urandom tr -dc _A-Z-a-z-0-9 | head -c32
}

check_user "root" "This script can only be run by root"

mkdir -p "$OUTPUT_FOLDER"

## Resolver Service
# Create a CA, create a private and issue a certificate for the resolver service
gen_ca_issue_cert "$OUTPUT_FOLDER" "dcv_gateway" "/C=US/CN=DCV Gateway Dev Resolver Service CA" || die "Error while creating the Gateway certificates"

_jks_password="$(generate_jks_password)"

keytool -import -noprompt -file "${OUTPUT_FOLDER}/dcv_gateway_ca_cert.pem" -storepass "$_jks_password" -keystore "${OUTPUT_FOLDER}/resolver-api-trust-store.jks" || die "Error while creating the TrustStore"

echo "Gateway integration credentials have been generated in $OUTPUT_FOLDER"
echo "TrustStore password: $_jks_password"